@@ -4,7 +4,7 @@ package Thread::Pool::Resolve;
 # Make sure we inherit from Thread::Pool
 # Make sure we do everything by the book from now on
 
-$VERSION = '0.09';
+$VERSION = '0.10';
 @ISA = qw(Thread::Pool);
 use strict;
 
@@ -548,6 +548,8 @@ sub _word {
 
 #---------------------------------------------------------------------------
 
+__END__
+
 =head1 NAME
 
 Thread::Pool::Resolve - resolve logs asynchronously
@@ -1105,6 +1107,11 @@ that roughly conforms to what is considered to be a valid IP number
 periods).  It can be used to create test log files (as is done in the
 test-suite of this module).
 
+=head1 REQUIRED MODULES
+
+ load (any)
+ Thread::Pool (0.29)
+
 =head1 BUGS
 
 Release 5.8.0 of Perl has a bug related to the usage of signals with threads.
